DailyTasksApi class

A class to handle API interactions related to daily tasks (gamification).

Constructors

DailyTasksApi({required Dio dio, required String baseUrl, required String apiKey})
Constructs a DailyTasksApi instance.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

claim({required String taskKey, required String companyId}) Future<ApiResponseModel<int?>>
Claims XP reward for completing a daily task.
claimBonus({required String companyId}) Future<ApiResponseModel<int?>>
Claims the all-tasks-completed bonus.
getProfile({required String companyId}) Future<ApiResponseModel<GameProfileModel?>>
Gets the user's game profile (XP, level, streak).
list({required String companyId}) Future<ApiResponseModel<List<DailyTaskModel>>>
Lists today's daily tasks for the user.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited