CompanyModel class

Constructors

CompanyModel({String? id, required String name, String? description, String? address, String? city, Country? country, CompanyVerificationStatus verificationStatus = CompanyVerificationStatus.pending, String? verificationReason, String? companyTypeId, required String ownerId, required DateTime createdAt, DateTime? updatedAt})
CompanyModel.fromJson(Map<String, dynamic> json)
factory

Properties

address String?
final
box → BoxBase?
Get the box in which this object is stored. Returns null if object has not been added to a box yet.
no setterinherited
city String?
final
companyTypeId String?
final
country Country?
final
createdAt DateTime
final
description String?
final
hashCode int
The hash code for this object.
no setterinherited
id String?
final
isInBox bool
Returns whether this object is currently stored in a box.
no setterinherited
key → dynamic
Get the key associated with this object. Returns null if object has not been added to a box yet.
no setterinherited
final
name String
final
ownerId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updatedAt DateTime?
final
verificationReason String?
final
verificationStatus CompanyVerificationStatus
final

Methods

delete() Future<void>
Deletes this object from the box it is stored in.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
save() Future<void>
Persists this object.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited